import { __classPrivateFieldSet, __classPrivateFieldGet } from '../_virtual/_tslib.js';
import moment from 'moment';
import { cloneDeep } from 'lodash';

var _SlotCalculator_instances, _SlotCalculator_slotPreferences, _SlotCalculator_scheduledTimesWithZone, _SlotCalculator_postCategories, _SlotCalculator_timezone, _SlotCalculator_categoryMatchingStrategy, _SlotCalculator_doCategoriesMatch, _SlotCalculator_getNewDayMomentInTimezone, _SlotCalculator_getMomentNow, _SlotCalculator_getSlotsForDay;
class SlotCalculator {
    constructor({ slotPreferences, scheduledTimesWithZone, postCategories, timezone }) {
        _SlotCalculator_instances.add(this);
        _SlotCalculator_slotPreferences.set(this, void 0);
        _SlotCalculator_scheduledTimesWithZone.set(this, void 0);
        _SlotCalculator_postCategories.set(this, void 0);
        _SlotCalculator_timezone.set(this, void 0);
        _SlotCalculator_categoryMatchingStrategy.set(this, 'any');
        __classPrivateFieldSet(this, _SlotCalculator_slotPreferences, slotPreferences, "f");
        __classPrivateFieldSet(this, _SlotCalculator_scheduledTimesWithZone, scheduledTimesWithZone, "f");
        __classPrivateFieldSet(this, _SlotCalculator_postCategories, postCategories, "f");
        __classPrivateFieldSet(this, _SlotCalculator_timezone, timezone, "f");
        __classPrivateFieldSet(this, _SlotCalculator_categoryMatchingStrategy, 'all', "f");
    }
    getConfig() {
        return cloneDeep({
            slotPreferences: __classPrivateFieldGet(this, _SlotCalculator_slotPreferences, "f"),
            scheduledTimesWithZone: __classPrivateFieldGet(this, _SlotCalculator_scheduledTimesWithZone, "f"),
            postCategories: __classPrivateFieldGet(this, _SlotCalculator_postCategories, "f"),
            timezone: __classPrivateFieldGet(this, _SlotCalculator_timezone, "f")
        });
    }
    getNextEmptySlot() {
        const dayMoment = __classPrivateFieldGet(this, _SlotCalculator_instances, "m", _SlotCalculator_getNewDayMomentInTimezone).call(this);
        let emptySlot = dayMoment;
        let emptySlotFound = false;
        while (dayMoment.diff(__classPrivateFieldGet(this, _SlotCalculator_instances, "m", _SlotCalculator_getMomentNow).call(this), 'days') < 730 && !emptySlotFound) {
            const slotsInDay = __classPrivateFieldGet(this, _SlotCalculator_instances, "m", _SlotCalculator_getSlotsForDay).call(this, dayMoment);
            for (const slot of slotsInDay) {
                if (slot.canBeScheduled) {
                    emptySlotFound = true;
                    emptySlot = slot.slotTime;
                    break;
                }
            }
            if (emptySlotFound) {
                break;
            }
            dayMoment.add(1, 'day');
        }
        if (emptySlotFound) {
            return emptySlot;
        }
        throw new Error('No valid slot found in the next 2 years. Try changing your slot preferences and categories and try again.');
    }
}
_SlotCalculator_slotPreferences = new WeakMap(), _SlotCalculator_scheduledTimesWithZone = new WeakMap(), _SlotCalculator_postCategories = new WeakMap(), _SlotCalculator_timezone = new WeakMap(), _SlotCalculator_categoryMatchingStrategy = new WeakMap(), _SlotCalculator_instances = new WeakSet(), _SlotCalculator_doCategoriesMatch = function _SlotCalculator_doCategoriesMatch(allowedCategories) {
    if (allowedCategories.length === 0) {
        return true;
    }
    if (__classPrivateFieldGet(this, _SlotCalculator_categoryMatchingStrategy, "f") === 'any') {
        return __classPrivateFieldGet(this, _SlotCalculator_postCategories, "f").some(postCategory => allowedCategories.includes(postCategory));
    }
    else {
        return __classPrivateFieldGet(this, _SlotCalculator_postCategories, "f").every(postCategory => allowedCategories.includes(postCategory));
    }
}, _SlotCalculator_getNewDayMomentInTimezone = function _SlotCalculator_getNewDayMomentInTimezone(dateMoment = moment()) {
    return moment(dateMoment).utcOffset(__classPrivateFieldGet(this, _SlotCalculator_timezone, "f")).startOf('day');
}, _SlotCalculator_getMomentNow = function _SlotCalculator_getMomentNow() {
    return moment().utcOffset(__classPrivateFieldGet(this, _SlotCalculator_timezone, "f"));
}, _SlotCalculator_getSlotsForDay = function _SlotCalculator_getSlotsForDay(dayMomentWithZone) {
    const dayOfWeek = dayMomentWithZone.format('dddd').toLowerCase();
    const slotPreferencesForDay = __classPrivateFieldGet(this, _SlotCalculator_slotPreferences, "f")[dayOfWeek];
    if (!slotPreferencesForDay)
        return [{
                hasSlots: false,
                canBeScheduled: false
            }];
    const slotsInDay = slotPreferencesForDay.map(slotPreference => {
        const slotTime = __classPrivateFieldGet(this, _SlotCalculator_instances, "m", _SlotCalculator_getNewDayMomentInTimezone).call(this, dayMomentWithZone).add(moment.duration(slotPreference.time));
        return {
            slotTime,
            allowedCategories: slotPreference.allowedCategories,
            canBeScheduled: slotTime.isAfter(__classPrivateFieldGet(this, _SlotCalculator_instances, "m", _SlotCalculator_getMomentNow).call(this)) && __classPrivateFieldGet(this, _SlotCalculator_instances, "m", _SlotCalculator_doCategoriesMatch).call(this, slotPreference.allowedCategories) && !__classPrivateFieldGet(this, _SlotCalculator_scheduledTimesWithZone, "f").some(scheduledTimeWithZone => moment(scheduledTimeWithZone).isSame(slotTime))
        };
    });
    return slotsInDay;
};
function getNextAvailableSlotTime(args) {
    return new SlotCalculator(args).getNextEmptySlot().toDate();
}

export { SlotCalculator, getNextAvailableSlotTime };
