import { Moment } from 'moment';

declare type Category = string;
declare type DaySlot = {
    time: string;
    allowedCategories: Category[];
};
declare type DayOfWeek = 'monday' | 'tuesday' | 'wednesday' | 'thursday' | 'friday' | 'saturday' | 'sunday';
declare type SlotPreferences = Exclude<Partial<{
    [K in DayOfWeek]: DaySlot[];
}>, Record<string, never>>;

interface definitions {
    linkedin_carousel_posts: {
        /**
         * Format: bigint
         * @description Note:
         * This is a Primary Key.<pk/>
         */
        id: number;
        /**
         * Format: timestamp with time zone
         * @default now()
         */
        created_at?: string;
        /**
         * Format: character varying
         * @default
         */
        title?: string;
        /**
         * Format: text
         * @default
         */
        description?: string;
        /**
         * Format: timestamp with time zone
         * @default now()
         */
        updated_at?: string;
        /**
         * Format: character varying
         * @default DRAFT
         */
        status?: string;
        /** Format: timestamp with time zone */
        scheduled_at?: string;
    };
    user_teams_list: {
        /**
         * Format: uuid
         * @description Note:
         * This is a Primary Key.<pk/>
         */
        user_id?: string;
        /** Format: character varying */
        user_email?: string;
        /** Format: text */
        username?: string;
        /** Format: bigint */
        team_id?: number;
        /** Format: character varying */
        team_name?: string;
    };
    instagram_carousel_posts: {
        /**
         * Format: bigint
         * @description Note:
         * This is a Primary Key.<pk/>
         */
        id: number;
        /**
         * Format: timestamp with time zone
         * @default now()
         */
        created_at?: string;
        /**
         * Format: character varying
         * @default
         */
        title?: string;
        /**
         * Format: text
         * @default
         */
        description?: string;
        /**
         * Format: timestamp with time zone
         * @default now()
         */
        updated_at?: string;
        /**
         * Format: character varying
         * @default DRAFT
         */
        status?: string;
        /** Format: timestamp with time zone */
        scheduled_at?: string;
    };
    social_providers: {
        /**
         * Format: uuid
         * @description Note:
         * This is a Primary Key.<pk/>
         * @default extensions.uuid_generate_v4()
         */
        id: string;
        /**
         * Format: timestamp with time zone
         * @default (now() AT TIME ZONE 'utc'::text)
         */
        created_at: string;
        /**
         * Format: timestamp with time zone
         * @default (now() AT TIME ZONE 'utc'::text)
         */
        updated_at: string;
        /**
         * Format: text
         * @description Twitter token type
         */
        twitter_token_type?: string;
        /**
         * Format: text
         * @description Twitter access token of user
         */
        twitter_access_token?: string;
        /**
         * Format: text
         * @description Twitter refresh token of user
         */
        twitter_refresh_token?: string;
        /** Format: timestamp with time zone */
        twitter_access_token_expires_at?: string;
        /** Format: text */
        twitter_code_challenge?: string;
        /**
         * Format: text
         * @description Access token for linkedin
         */
        linkedin_access_token?: string;
        /**
         * Format: timestamp with time zone
         * @description When linkedin access token expires
         */
        linkedin_access_token_expires_at?: string;
        /**
         * Format: text
         * @description The state variable sent while connecting to linkedin
         */
        linkedin_connect_unique_state?: string;
        /**
         * Format: text
         * @description Access token for facebook
         */
        facebook_access_token?: string;
        /**
         * Format: timestamp with time zone
         * @description Expires at for facebook
         */
        facebook_access_token_expires_at?: string;
        /**
         * Format: ARRAY
         * @description Granted scopes by Facebook
         */
        facebook_granted_scopes?: unknown[];
        /**
         * Format: ARRAY
         * @description Facebooks granted granular scopes
         */
        facebook_granted_granular_scopes?: unknown[];
        /**
         * Format: bigint
         * @description Note:
         * This is a Foreign Key to `teams.id`.<fk table='teams' column='id'/>
         */
        team_id?: number;
        /**
         * Format: text
         * @description Twitter's unique id for the user
         */
        twitter_id?: string;
        /** Format: character varying */
        linkedin_user_id?: string;
        /** Format: character varying */
        twitter_username?: string;
        /** Format: character varying */
        linkedin_vanity_name?: string;
        /** Format: text */
        twitter_profile_image_url?: string;
        /** Format: character varying */
        twitter_description?: string;
        /** Format: character varying */
        twitter_url?: string;
        /** Format: character varying */
        twitter_name?: string;
        /** Format: timestamp with time zone */
        twitter_created_at?: string;
        /** Format: boolean */
        twitter_verified?: boolean;
        /** Format: boolean */
        twitter_withheld?: boolean;
        /**
         * Format: character varying
         * @description User id of the user on facebook
         */
        facebook_user_id?: string;
        /**
         * Format: character varying
         * @description ID of the instagram business account
         */
        instagram_business_account_id?: string;
        /**
         * Format: character varying
         * @description ID of the facebook page associated with the instagram business account
         */
        facebook_page_id?: string;
        /**
         * Format: character varying
         * @description Long lived access token
         */
        instagram_long_lived_access_token?: string;
        /** Format: character varying */
        instagram_profile_picture_url?: string;
        /** Format: character varying */
        instagram_username?: string;
        /** Format: character varying */
        instagram_name?: string;
        /**
         * Format: character varying
         * @description Instagram account type
         */
        instagram_account_type?: string;
        /** Format: timestamp with time zone */
        instagram_long_lived_access_token_expires_at?: string;
        /** Format: character varying */
        linkedin_first_name?: string;
        /** Format: character varying */
        linkedin_last_name?: string;
        /** Format: character varying */
        linkedin_profile_picture_url?: string;
    };
    /** @description Teams of the user */
    teams: {
        /**
         * Format: bigint
         * @description Note:
         * This is a Primary Key.<pk/>
         */
        id: number;
        /**
         * Format: timestamp with time zone
         * @default now()
         */
        created_at?: string;
        /**
         * Format: uuid
         * @description Note:
         * This is a Foreign Key to `user_teams_list.user_id`.<fk table='user_teams_list' column='user_id'/>
         */
        owner_user_uuid: string;
        /**
         * Format: character varying
         * @default personal
         */
        name?: string;
        /**
         * Format: character varying
         * @default STARTER
         */
        subscription: string;
        /**
         * Format: character varying
         * @default personal
         */
        slug?: string;
    };
    studio_images: {
        /**
         * Format: bigint
         * @description Note:
         * This is a Primary Key.<pk/>
         */
        id: number;
        /**
         * Format: timestamp with time zone
         * @default now()
         */
        created_at?: string;
        /**
         * Format: timestamp with time zone
         * @default now()
         */
        updated_at?: string;
        /** Format: uuid */
        identifier?: string;
        /**
         * Format: bigint
         * @description Note:
         * This is a Foreign Key to `teams.id`.<fk table='teams' column='id'/>
         */
        team_id?: number;
        /** Format: text */
        extracted_text?: string;
    };
    /** @description Slot for scheduling */
    content_slots: {
        /**
         * Format: bigint
         * @description Note:
         * This is a Primary Key.<pk/>
         */
        id: number;
        /**
         * Format: timestamp with time zone
         * @default now()
         */
        created_at: string;
        /**
         * Format: timestamp with time zone
         * @default now()
         */
        updated_at: string;
        /**
         * Format: bigint
         * @description Note:
         * This is a Foreign Key to `teams.id`.<fk table='teams' column='id'/>
         */
        team_id?: number;
        /**
         * Format: time with time zone
         * @default now()
         */
        time?: string;
        /**
         * Format: character varying
         * @default monday
         */
        day_of_week?: string;
        /** Format: ARRAY */
        labels?: unknown[];
    };
    content_labels: {
        /**
         * Format: bigint
         * @description Note:
         * This is a Primary Key.<pk/>
         */
        id: number;
        /**
         * Format: timestamp with time zone
         * @default now()
         */
        created_at?: string;
        /**
         * Format: timestamp with time zone
         * @default now()
         */
        updated_at?: string;
        /** Format: character varying */
        name: string;
        /**
         * Format: bigint
         * @description Note:
         * This is a Foreign Key to `teams.id`.<fk table='teams' column='id'/>
         */
        team_id?: number;
        /**
         * Format: text
         * @default default
         */
        color_variant?: string;
    };
    /** @description Members of a team */
    team_members: {
        /**
         * Format: bigint
         * @description Note:
         * This is a Primary Key.<pk/>
         */
        id: number;
        /**
         * Format: timestamp with time zone
         * @default now()
         */
        created_at?: string;
        /**
         * Format: uuid
         * @description Note:
         * This is a Foreign Key to `user_teams_list.user_id`.<fk table='user_teams_list' column='user_id'/>
         */
        member_uuid?: string;
        /**
         * Format: bigint
         * @description Note:
         * This is a Foreign Key to `teams.id`.<fk table='teams' column='id'/>
         */
        team_id?: number;
        /**
         * Format: character varying
         * @description Role of the member
         * @default CREATOR
         */
        member_role?: string;
    };
    profiles: {
        /**
         * Format: uuid
         * @description Note:
         * This is a Primary Key.<pk/>
         * This is a Foreign Key to `user_teams_list.user_id`.<fk table='user_teams_list' column='user_id'/>
         */
        id: string;
        /** Format: timestamp with time zone */
        updated_at?: string;
        /** Format: text */
        username?: string;
        /** Format: text */
        avatar_url?: string;
        /** Format: text */
        website?: string;
        /**
         * Format: boolean
         * @description Whether a user is a test user or not
         * @default false
         */
        is_test_user: boolean;
        /**
         * Format: timestamp with time zone
         * @default (now() AT TIME ZONE 'utc'::text)
         */
        created_at?: string;
        /** Format: character varying */
        stripe_customer_id?: string;
        /**
         * Format: boolean
         * @default false
         */
        is_super_user: boolean;
    };
    /** @description Posts */
    posts: {
        /**
         * Format: bigint
         * @description Note:
         * This is a Primary Key.<pk/>
         */
        id: number;
        /**
         * Format: timestamp with time zone
         * @default now()
         */
        created_at?: string;
        /**
         * Format: timestamp with time zone
         * @default (now() AT TIME ZONE 'utc'::text)
         */
        updated_at: string;
        /** Format: ARRAY */
        contents?: unknown[];
        /**
         * Format: character varying
         * @default DRAFT
         */
        status?: string;
        /** Format: ARRAY */
        twitter_variation_contents?: unknown[];
        /** Format: ARRAY */
        linkedin_variation_contents?: unknown[];
        /** Format: timestamp with time zone */
        published_at?: string;
        /** Format: timestamp with time zone */
        scheduled_at?: string;
        /**
         * Format: bigint
         * @description Id of the team
         *
         * Note:
         * This is a Foreign Key to `teams.id`.<fk table='teams' column='id'/>
         */
        team_id: number;
        /**
         * Format: uuid
         * @description Note:
         * This is a Foreign Key to `user_teams_list.user_id`.<fk table='user_teams_list' column='user_id'/>
         */
        uploaded_by_user_uuid: string;
        /** Format: timestamp with time zone */
        twitter_scheduled_at?: string;
        /** Format: timestamp with time zone */
        linkedin_scheduled_at?: string;
    };
    scheduled_posts: {
        /**
         * Format: bigint
         * @description Note:
         * This is a Primary Key.<pk/>
         */
        id?: number;
        /** Format: ARRAY */
        contents?: unknown[];
        /** Format: character varying */
        status?: string;
        /** Format: ARRAY */
        twitter_variation_contents?: unknown[];
        /** Format: ARRAY */
        linkedin_variation_contents?: unknown[];
        /** Format: uuid */
        social_providers_id?: string;
        /**
         * Format: bigint
         * @description Note:
         * This is a Foreign Key to `teams.id`.<fk table='teams' column='id'/>
         */
        team_id?: number;
        /** Format: timestamp with time zone */
        scheduled_at?: string;
        /** Format: timestamp with time zone */
        twitter_scheduled_at?: string;
        /** Format: timestamp with time zone */
        linkedin_scheduled_at?: string;
        /** Format: text */
        twitter_access_token?: string;
        /** Format: text */
        linkedin_access_token?: string;
        /** Format: timestamp with time zone */
        twitter_access_token_expires_at?: string;
        /** Format: text */
        twitter_refresh_token?: string;
    };
    goat_tester_details: {
        /**
         * Format: uuid
         * @description Note:
         * This is a Primary Key.<pk/>
         */
        id?: string;
        /** Format: timestamp with time zone */
        created_at?: string;
        /** Format: timestamp with time zone */
        updated_at?: string;
        /** Format: text */
        twitter_token_type?: string;
        /** Format: text */
        twitter_access_token?: string;
        /** Format: text */
        twitter_refresh_token?: string;
        /** Format: timestamp with time zone */
        twitter_access_token_expires_at?: string;
        /** Format: text */
        twitter_code_challenge?: string;
        /** Format: text */
        linkedin_access_token?: string;
        /** Format: timestamp with time zone */
        linkedin_access_token_expires_at?: string;
        /** Format: text */
        linkedin_connect_unique_state?: string;
        /** Format: text */
        facebook_access_token?: string;
        /** Format: timestamp with time zone */
        facebook_access_token_expires_at?: string;
        /** Format: ARRAY */
        facebook_granted_scopes?: unknown[];
        /** Format: ARRAY */
        facebook_granted_granular_scopes?: unknown[];
        /**
         * Format: bigint
         * @description Note:
         * This is a Foreign Key to `teams.id`.<fk table='teams' column='id'/>
         */
        team_id?: number;
        /** Format: text */
        twitter_id?: string;
        /** Format: character varying */
        linkedin_user_id?: string;
        /** Format: character varying */
        twitter_username?: string;
        /** Format: character varying */
        linkedin_vanity_name?: string;
        /** Format: text */
        twitter_profile_image_url?: string;
        /** Format: character varying */
        twitter_description?: string;
        /** Format: character varying */
        twitter_url?: string;
        /** Format: character varying */
        twitter_name?: string;
        /** Format: timestamp with time zone */
        twitter_created_at?: string;
        /** Format: boolean */
        twitter_verified?: boolean;
        /** Format: boolean */
        twitter_withheld?: boolean;
        /** Format: character varying */
        facebook_user_id?: string;
        /** Format: character varying */
        instagram_business_account_id?: string;
        /** Format: character varying */
        facebook_page_id?: string;
        /** Format: character varying */
        instagram_long_lived_access_token?: string;
        /** Format: character varying */
        instagram_profile_picture_url?: string;
        /** Format: character varying */
        instagram_username?: string;
        /** Format: character varying */
        instagram_name?: string;
        /** Format: character varying */
        instagram_account_type?: string;
        /** Format: timestamp with time zone */
        instagram_long_lived_access_token_expires_at?: string;
        /** Format: character varying */
        linkedin_first_name?: string;
        /** Format: character varying */
        linkedin_last_name?: string;
        /** Format: character varying */
        linkedin_profile_picture_url?: string;
    };
}

declare type ScheduledTime = Exclude<Required<definitions['posts']['scheduled_at']>, undefined>;
declare type SlotConstructorArgs = {
    slotPreferences: SlotPreferences;
    scheduledTimesWithZone: ScheduledTime[];
    postCategories: Category[];
    timezone: string;
};
declare class SlotCalculator {
    #private;
    constructor({ slotPreferences, scheduledTimesWithZone, postCategories, timezone }: SlotConstructorArgs);
    getConfig(): {
        slotPreferences: Partial<{
            monday: DaySlot[];
            tuesday: DaySlot[];
            wednesday: DaySlot[];
            thursday: DaySlot[];
            friday: DaySlot[];
            saturday: DaySlot[];
            sunday: DaySlot[];
        }>;
        scheduledTimesWithZone: string[];
        postCategories: string[];
        timezone: string;
    };
    getNextEmptySlot(): Moment;
}
declare function getNextAvailableSlotTime(args: SlotConstructorArgs): Date;

export { Category, DayOfWeek, DaySlot, SlotCalculator, SlotPreferences, getNextAvailableSlotTime };
